@@ -34,6 +34,7 @@ def s3_prepare_node(region, account_id, cytoscape_node_data):
                     "account_id": account_id,
                     "name": item['Name'],
                     "CreationDate":item['CreationDate'],
-                    "tag":filtered_s3_tag
+                    "tag":filtered_s3_tag,
+                    "cost_for_month": "0.26 USD",
                 }
             })
